package com.bonus.material.warehouse.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
import com.bonus.material.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.material.warehouse.domain.WhHouseInfo;
import com.bonus.material.warehouse.service.IWhHouseInfoService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 仓库管理Controller
 * 
 * @author xsheng
 * @date 2024-09-27
 */
@Api(tags = "仓库管理接口")
@RestController
@RequestMapping("/wh_house_info")
public class WhHouseInfoController extends BaseController {

    @Autowired
    private IWhHouseInfoService whHouseInfoService;

    /**
     * 查询仓库管理列表
     */
    @ApiOperation(value = "查询仓库管理列表")
    @RequiresPermissions("warehouse:info:list")
    @GetMapping("/list")
    public TableDataInfo list(WhHouseInfo whHouseInfo) {
        startPage();
        List<WhHouseInfo> list = whHouseInfoService.selectWhHouseInfoList(whHouseInfo);
        return getDataTable(list);
    }

    /**
     * 查询仓库列表 -- 不分页
     */
    @ApiOperation(value = "查询仓库列表--不分页")
    @RequiresPermissions("warehouse:info:list")
    @GetMapping("/listNoPage")
    public AjaxResult listNoPage(WhHouseInfo whHouseInfo) {
        List<WhHouseInfo> list = whHouseInfoService.selectWhHouseInfoList(whHouseInfo);
        return success(list);
    }

    /**
     * 导出仓库管理列表
     */
    @ApiOperation(value = "导出仓库管理列表")
    @PreventRepeatSubmit
    @RequiresPermissions("warehouse:info:export")
    @SysLog(title = "仓库管理", businessType = OperaType.EXPORT, module = "仓储管理->导出仓库管理")
    @PostMapping("/export")
    public void export(HttpServletResponse response, WhHouseInfo whHouseInfo) {
        List<WhHouseInfo> list = whHouseInfoService.selectWhHouseInfoList(whHouseInfo);
        ExcelUtil<WhHouseInfo> util = new ExcelUtil<WhHouseInfo>(WhHouseInfo.class);
        util.exportExcel(response, list, "仓库管理数据");
    }

    /**
     * 获取仓库管理详细信息
     */
    @ApiOperation(value = "获取仓库管理详细信息")
    @RequiresPermissions("warehouse:info:query")
    @GetMapping(value = "/{houseId}")
    public AjaxResult getInfo(@PathVariable("houseId") Long houseId) {
        return success(whHouseInfoService.selectWhHouseInfoByHouseId(houseId));
    }

    /**
     * 新增仓库管理
     */
    @ApiOperation(value = "新增仓库管理")
    @PreventRepeatSubmit
    @RequiresPermissions("warehouse:info:add")
    @SysLog(title = "仓库管理", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增仓库管理")
    @PostMapping
    public AjaxResult add(@RequestBody WhHouseInfo whHouseInfo) {
        try {
            return toAjax(whHouseInfoService.insertWhHouseInfo(whHouseInfo));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 修改仓库管理
     */
    @ApiOperation(value = "修改仓库管理")
    @PreventRepeatSubmit
    @RequiresPermissions("warehouse:info:edit")
    @SysLog(title = "仓库管理", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改仓库管理")
    @PutMapping
    public AjaxResult edit(@RequestBody WhHouseInfo whHouseInfo) {
        try {
            return toAjax(whHouseInfoService.updateWhHouseInfo(whHouseInfo));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 删除仓库管理
     */
    @ApiOperation(value = "删除仓库管理")
    @PreventRepeatSubmit
    @RequiresPermissions("warehouse:info:remove")
    @SysLog(title = "仓库管理", businessType = OperaType.DELETE, module = "仓储管理->删除仓库管理")
	@DeleteMapping("/{houseIds}")
    public AjaxResult remove(@PathVariable Long[] houseIds) {
        return toAjax(whHouseInfoService.deleteWhHouseInfoByHouseIds(houseIds));
    }
}
